@@ -7,7 +7,10 @@ BiasVarPlot <- function(data, k1=1, k2=2, h, h2, output=FALSE, g, layout=TRUE) {
     basicCI.LL <- bias.out$basicCI.LL
     biasCI.LL <- bias.out$biasCI.LL
     biasCI.UL <- bias.out$biasCI.UL
-    if (layout) par(mfrow=c(2,1), mar=c(4,4,0,1))
+    if (layout) {
+        oldpar <- par(mfrow=c(2,1), mar=c(4,4,0,1))
+        on.exit(par(oldpar))
+    }
     y.range <- range(c(basicCI.UL, basicCI.LL))
     plot(x, basicCI.LL, ylim=y.range, type="l", ylab=names(xy)[2], xlab=
 names(xy)[1], lty=2)
